import java.awt.Polygon;

/**
 * Ein Dreieck, das manipuliert werden kann und sich selbst auf einer Leinwand
 * zeichnet.
 * 
 * @author Michael Klling und David J. Barnes
 * @version 2006.03.30
 * Fr die IBBB-Tagung 2007 leicht modifiziert von Alexander Dietz (04.03.2007)
 */

public class Dreieck {
	private int hoehe;

	private int breite;

	private int xPosition;

	private int yPosition;

	private String farbe;

	private boolean istSichtbar;

	/**
	 * Erzeuge ein Dreieck mit einer Standardfarbe an einer Standardposition.
	 */
	public Dreieck() {
		hoehe = 30;
		breite = 40;
		xPosition = 50;
		yPosition = 15;
		farbe = "gruen";
		istSichtbar = false;
	}
   /**
     * Erzeuge ein neues Dreieck. Die Startwerte knnen eingegeben werden.
     * @param x  die x-Koordinate des oberen Punktes 
     * @param y  die y-Koordinate des oberen Punktes 
     * @param b  die Breite des Dreiecks
     * @param h  die Hoehe des Dreiecks
     * @param f  die Farbe des Dreiecks ("rot", "gelb", "blau", "gruen", "lila", "schwarz")
     */
   public Dreieck(int x, int y, int b, int h, String f) {
     xPosition = x;
     yPosition = y;
     breite = b;
     hoehe = h;
     farbe = f;  
     istSichtbar = false;
   }

  /**
   * ndere die Breite dieses Dreiecks in 'neueBreite'.
   * @param neueBreite  die neue Breite des Dreiecks (groesser gleich 0)
   */
  public void setzeBreite(int neueBreite)
  {
   
    if (neueBreite>=0) {
       loeschen();   
       breite = neueBreite;
       zeichnen();
    }   
    else
      System.out.println("Diese Eingabe ist nicht plausibel.");
   
  }
  /**
   * ndere die Hoehe dieses Dreiecks in 'neueHoehe'.
  *  @param neueHoehe  die neue Hoehe des Dreiecks (groesser gleich 0)
   */
  public void setzeHoehe(int neueHoehe)
  {

    if (neueHoehe >= 0) {
        loeschen();  
        hoehe = neueHoehe;
        zeichnen();
    }   
    else
      System.out.println("Diese Eingabe ist nicht plausibel.");
   
  }

  /**
     * ndere die Position des Dreiecks
     * @param x  die x-Koordinate des oberen Punktes (groesser gleich 0)
     * @param y  die y-Koordinate des oberen Punktes (groesser gleich 0)
    */
	
   public void setzePosition(int x, int y) {
	  	
       if ((x>=0) && (y>=0)) {
            loeschen();
		    xPosition=x;
		    yPosition=y;
		    zeichnen();
		}    
		else 
		 System.out.println("Diese Eingabe ist nicht plausibel.");
	}


	/**
	 * Mache dieses Dreieck sichtbar. Wenn es bereits sichtbar ist, tue nichts.
	 */
	public void sichtbarMachen() {
		istSichtbar = true;
		zeichnen();
	}

	/**
	 * Mache dieses Dreieck unsichtbar. Wenn es bereits unsichtbar ist, tue
	 * nichts.
	 */
	public void unsichtbarMachen() {
		loeschen();
		istSichtbar = false;
	}

	/**
	 * Bewege dieses Dreieck einige Bildschirmpunkte nach rechts.
	 */
	public void nachRechtsBewegen() {
		horizontalBewegen(20);
	}

	/**
	 * Bewege dieses Dreieck einige Bildschirmpunkte nach links.
	 */
	public void nachLinksBewegen() {
		horizontalBewegen(-20);
	}

	/**
	 * Bewege dieses Dreieck einige Bildschirmpunkte nach oben.
	 */
	public void nachObenBewegen() {
		vertikalBewegen(-20);
	}

	/**
	 * Bewege dieses Dreieck einige Bildschirmpunkte nach unten.
	 */
	public void nachUntenBewegen() {
		vertikalBewegen(20);
	}

	/**
	 * Bewege dieses Dreieck horizontal um 'entfernung' Bildschirmpunkte.
	 * @param entfernung 
	 */
	public void horizontalBewegen(int entfernung) {
		loeschen();
		xPosition += entfernung;
		zeichnen();
	}

	/**
	 * Bewege dieses Dreieck vertikal um 'entfernung' Bildschirmpunkte.
	 * @param entfernung 
	 */
	public void vertikalBewegen(int entfernung) {
		loeschen();
		yPosition += entfernung;
		zeichnen();
	}

	/**
	 * Bewege dieses Dreieck langsam horizontal um 'entfernung'
	 * Bildschirmpunkte.
	 * @param entfernung 
	 */
	public void langsamHorizontalBewegen(int entfernung) {
		int delta;

		if (entfernung < 0) {
			delta = -1;
			entfernung = -entfernung;
		} else {
			delta = 1;
		}

		for (int i = 0; i < entfernung; i++) {
			xPosition += delta;
			zeichnen();
		}
	}

	/**
	 * Bewege dieses Dreieck langsam vertikal um 'entfernung' Bildschirmpunkte.
	 * @param entfernung 
	 */
	public void langsamVertikalBewegen(int entfernung) {
		int delta;

		if (entfernung < 0) {
			delta = -1;
			entfernung = -entfernung;
		} else {
			delta = 1;
		}

		for (int i = 0; i < entfernung; i++) {
			yPosition += delta;
			zeichnen();
		}
	}

	

	/**
	 * ndere die Farbe dieses Dreiecks in 'neueFarbe'. Gltige Angaben sind
	 * "rot", "gelb", "blau", "gruen", "lila" und "schwarz".
	 */
	public void farbeAendern(String neueFarbe) {
		farbe = neueFarbe;
		zeichnen();
	}

	/**
	 * Zeichne dieses Dreieck mit seinen aktuellen Werten auf den Bildschirm.
	 */
	private void zeichnen() {
		if (istSichtbar) {
			Leinwand leinwand = Leinwand.gibLeinwand();
			int[] xpoints = { xPosition, xPosition + (breite / 2),
					xPosition - (breite / 2) };
			int[] ypoints = { yPosition, yPosition + hoehe, yPosition + hoehe };
			leinwand.zeichne(this, farbe, new Polygon(xpoints, ypoints, 3));
			leinwand.warte(10);
		}
	}

	/**
	 * Lsche dieses Dreieck vom Bildschirm.
	 */
	private void loeschen() {
		if (istSichtbar) {
			Leinwand leinwand = Leinwand.gibLeinwand();
			leinwand.entferne(this);
		}
	}
}
