import java.awt.geom.Ellipse2D;

/**
 * Ein Kreis, der manipuliert werden kann und sich selbst auf einer Leinwand
 * zeichnet.
 * 
 * @author Michael Klling und David J. Barnes
 * @version 2006.03.30.
 * Fr die IBBB-Tagung 2007 leicht modifiziert von Alexander Dietz (04.03.2007)
 */

public class Kreis {
	private int durchmesser;

	private int xPosition;

	private int yPosition;

	private String farbe;

	private boolean istSichtbar;

    
	/**
	 * Erzeuge einen neuen Kreis an einer Standardposition mit einer
	 * Standardfarbe.
	 */
   public Kreis() {
		durchmesser = 30;
		xPosition = 20;
		yPosition = 60;
		farbe = "blau";
		istSichtbar = false;
	}
  
	/**
     * Erzeuge einen neuen Kreis. Die Startwerte knnen eingegeben werden.
     * @param x  die x-Koordinate des Kreismittelpunktes
     * @param y  die y-Koordinate des Kreismittelpunktes
     * @param d  der Durchmesser des Kreises
     * @param f  die Farbe des Rechteckes ("rot", "gelb", "blau", "gruen", "lila", "schwarz")
     */
   public Kreis(int x, int y, int d, String f) {
     xPosition = x;
     yPosition = y;
     durchmesser = d;
     farbe = f;  
     istSichtbar = false;
   }
    
	/**
	 * Mache diesen Kreis sichtbar. Wenn es bereits sichtbar ist, tue nichts.
	 */
	public void sichtbarMachen() {
		istSichtbar = true;
		zeichnen();
	}

	/**
	 * Mache diesen Kreis unsichtbar. Wenn es bereits unsichtbar ist, mache
	 * nichts.
	 */
	public void unsichtbarMachen() {
		loeschen();
		istSichtbar = false;
	}

	
	
	/**
	 * Bewege diesen Kreis einige Bildschirmpunkte nach rechts.
	 */
	public void nachRechtsBewegen() {
		horizontalBewegen(20);
	}

	/**
	 * Bewege diesen Kreis einige Bildschirmpunkte nach links.
	 */
	public void nachLinksBewegen() {
		horizontalBewegen(-20);
	}

	/**
	 * Bewege diesen Kreis einige Bildschirmpunkte nach oben.
	 */
	public void nachObenBewegen() {
		vertikalBewegen(-20);
	}

	/**
	 * Bewege diesen Kreis einige Bildschirmpunkte nach unten.
	 */
	public void nachUntenBewegen() {
		vertikalBewegen(20);
	}

	/**
	 * Bewege diesen Kreis horizontal um 'entfernung' Bildschirmpunkte.
	 * @param entfernung  
	 */
	public void horizontalBewegen(int entfernung) {
		loeschen();
		xPosition += entfernung;
		zeichnen();
	}

	/**
	 * Bewege diesen Kreis vertikal um 'entfernung' Bildschirmpunkte.
	 * @param entfernung  
	 */
	public void vertikalBewegen(int entfernung) {
		loeschen();
		yPosition += entfernung;
		zeichnen();
	}

	/**
	 * Bewege diesen Kreis langsam horizontal um 'entfernung' Bildschirmpunkte.
	 * @param entfernung  
	 */
	public void langsamHorizontalBewegen(int entfernung) {
		int delta;

		if (entfernung < 0) {
			delta = -1;
			entfernung = -entfernung;
		} else {
			delta = 1;
		}

		for (int i = 0; i < entfernung; i++) {
			xPosition += delta;
			zeichnen();
		}
	}

	/**
	 * Bewege diesen Kreis langsam vertikal um 'entfernung' Bildschirmpunkte.
	 * @param entfernung  
	 */
	public void langsamVertikalBewegen(int entfernung) {
		int delta;

		if (entfernung < 0) {
			delta = -1;
			entfernung = -entfernung;
		} else {
			delta = 1;
		}

		for (int i = 0; i < entfernung; i++) {
			yPosition += delta;
			zeichnen();
		}
	}

	/**
	 * ndere den Durchmesser dieses Kreises in 'neuerDurchmesser' (Angabe in
	 * Bildschirmpunkten). 'neuerDurchmesser' muss grer gleich Null sein.
	 * @param neuerDurchmesser  der neue Durchmesser 
	 */
	public void setzeDurchmesser(int neuerDurchmesser) {
		loeschen();
		if (durchmesser>=0)
		   durchmesser = neuerDurchmesser;
		else   
		   System.out.println("Diese Eingabe ist nicht plausibel.");
		zeichnen();
	}
	
  
    /**
     * ndere die Position des Kreises
     * 'neuesX' und 'neuesY' mssen grer gleich Null sein.
     * @param neuesX  die neue x-Koordinate des Kreismittelpunktes
     * @param neuesY  die neue y-Koordinate des Kreismittelpunktes
     */
	public void setzePosition(int neuesX, int neuesY) {
	   loeschen();	
       if ((neuesX>=0) && (neuesY>=0)) {
		    xPosition=neuesX;
		    yPosition=neuesY;
		}    
		else 
		 System.out.println("Diese Eingabe ist nicht plausibel.");
	   zeichnen();
     }

	/**
	 * ndere die Farbe dieses Kreises in 'neueFarbe'. Gltige Angaben sind
	 * "rot", "gelb", "blau", "gruen", "lila" und "schwarz".
	 * @param neueFarbe  
	 */
	public void farbeAendern(String neueFarbe) {
		farbe = neueFarbe;
		zeichnen();
	}

	/**
	 * Zeichne diesen Kreis mit seinen aktuellen Werten auf den Bildschirm.
	 */
	private void zeichnen() {
		if (istSichtbar) {
			Leinwand leinwand = Leinwand.gibLeinwand();
			leinwand.zeichne(this, farbe, new Ellipse2D.Double(xPosition,
					yPosition, durchmesser, durchmesser));
			leinwand.warte(10);
		}
	}

	/**
	 * Lsche diesen Kreis vom Bildschirm.
	 */
	private void loeschen() {
		if (istSichtbar) {
			Leinwand leinwand = Leinwand.gibLeinwand();
			leinwand.entferne(this);
		}
	}

}
