import java.awt.Rectangle;

/**
 * Ein Quadrat, das manipuliert werden kann und sich selbst auf einer Leinwand
 * zeichnet.
 * 
 * @author Michael Klling und David J. Barnes
 * @version 2006.03.30.
 * Fr die IBBB-Tagung 2007 leicht modifiziert von Alexander Dietz (04.03.2007)
 */

public class Quadrat {
	private int laenge;

	private int xPosition;

	private int yPosition;

	private String farbe;

	private boolean istSichtbar;

	/**
	 * Erzeuge ein neues Quadrat mit einer Standardfarbe an einer
	 * Standardposition.
	 */
	public Quadrat() {
		laenge = 30;
		xPosition = 60;
		yPosition = 50;
		farbe = "rot";
		istSichtbar = false;
	}
	
	/**
     * Erzeuge ein neues Quadrat. Die Startwerte knnen eingegeben werden.
     * @param x  die x-Koordinate des linken oberen Eckpunktes 
     * @param y  die y-Koordinate des linken oberen Eckpunktes 
     * @param l  die Seitenlaenge des Quadrates
     * @param f  die Farbe des Quadrates ("rot", "gelb", "blau", "gruen", "lila", "schwarz")
     */
   public Quadrat(int x, int y, int l, String f) {
     xPosition = x;
     yPosition = y;
     laenge = l;
     farbe = f;  
     istSichtbar = false;
   }
	

  /**
   * ndere die Seitenlaenge dieses Quadrates in 'l'.
   * @param l  die neue Seitenlaenge des Quadrates (groesser gleich 0)
   */
  public void setzeSeitenlaenge(int l)
  {
    loeschen();  
    if (l>=0)
       laenge = l;
    else
      System.out.println("Diese Eingabe ist nicht plausibel.");
    
    zeichnen();  
  }

  /**
     * ndere die Position des Quadrates. 
     * @param x  die x-Koordinate des linken oberen Eckpunktes 
     * @param y  die y-Koordinate des linken oberen Eckpunktes 
    */
	
   public void setzePosition(int x, int y) {
        loeschen();
		if ((x>=0) && (y>=0)) {
		    xPosition=x;
		    yPosition=y;
		}    
		else 
		 System.out.println("Diese Eingabe ist nicht plausibel.");
	    zeichnen();
   }

	/**
	 * Mache dieses Quadrat sichtbar. Wenn es bereits sichtbar ist, tue nichts.
	 */
	public void sichtbarMachen() {
		istSichtbar = true;
		zeichnen();
	}

	/**
	 * Mache dieses Quadrat unsichtbar. Wenn es bereits unsichtbar ist, tue
	 * nichts.
	 */
	public void unsichtbarMachen() {
		loeschen();
		istSichtbar = false;
	}

	/**
	 * Bewege dieses Quadrat einige Bildschirmpunkte nach rechts.
	 */
	public void nachRechtsBewegen() {
		horizontalBewegen(20);
	}

	/**
	 * Bewege dieses Quadrat einige Bildschirmpunkte nach links.
	 */
	public void nachLinksBewegen() {
		horizontalBewegen(-20);
	}

	/**
	 * Bewege dieses Quadrat einige Bildschirmpunkte nach oben.
	 */
	public void nachObenBewegen() {
		vertikalBewegen(-20);
	}

	/**
	 * Bewege dieses Quadrat einige Bildschirmpunkte nach unten.
	 */
	public void nachUntenBewegen() {
		vertikalBewegen(20);
	}

	/**
	 * Bewege dieses Quadrat horizontal um 'entfernung' Bildschirmpunkte.
	 * @param entfernung
 
	 */
	public void horizontalBewegen(int entfernung) {
		loeschen();
		xPosition += entfernung;
		zeichnen();
	}

	/**
	 * Bewege dieses Quadrat vertikal um 'entfernung' Bildschirmpunkte.
	 */
	public void vertikalBewegen(int entfernung) {
		loeschen();
		yPosition += entfernung;
		zeichnen();
	}

	/**
	 * Bewege dieses Quadrat langsam horizontal um 'entfernung'
	 * Bildschirmpunkte.
	 */
	public void langsamHorizontalBewegen(int entfernung) {
		int delta;

		if (entfernung < 0) {
			delta = -1;
			entfernung = -entfernung;
		} else {
			delta = 1;
		}

		for (int i = 0; i < entfernung; i++) {
			xPosition += delta;
			zeichnen();
		}
	}

	/**
	 * Bewege dieses Quadrat langsam vertikal um 'entfernung' Bildschirmpunkte.
	 */
	public void langsamVertikalBewegen(int entfernung) {
		int delta;

		if (entfernung < 0) {
			delta = -1;
			entfernung = -entfernung;
		} else {
			delta = 1;
		}

		for (int i = 0; i < entfernung; i++) {
			yPosition += delta;
			zeichnen();
		}
	}

	

	/**
	 * ndere die Farbe dieses Quadrates in 'neueFarbe'. Gltige Angaben sind
	 * "rot", "gelb", "blau", "gruen", "lila" und "schwarz".
	 */
	public void farbeAendern(String neueFarbe) {
		farbe = neueFarbe;
		zeichnen();
	}

	/**
	 * Zeichne dieses Quadrat mit seinen aktuellen Werten auf den Bildschirm.
	 */
	private void zeichnen() {
		if (istSichtbar) {
			Leinwand leinwand = Leinwand.gibLeinwand();
			leinwand.zeichne(this, farbe, new Rectangle(xPosition, yPosition,
					laenge, laenge));
			leinwand.warte(10);
		}
	}

	/**
	 * Lsche dieses Quadrat vom Bildschirm.
	 */
	private void loeschen() {
		if (istSichtbar) {
			Leinwand leinwand = Leinwand.gibLeinwand();
			leinwand.entferne(this);
		}
	}
}
